==> am_mod_grp_0_1.zip: am_mod_grp_0_1/components/grp/template/barnraiser_01/metadata.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>


<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<span style="float:left">
				<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('components/core/help.php?help=core_tag#module_tags');" />
			</span>
			
			<?php echo $lang['hdr_cloud'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($group_tags)) {
				?>
				<p>
					<b><?php echo $lang['txt_tag_group'];?></b><br />
					<?php
					$prnt = "";
					foreach($group_tags as $key => $i):
					
						$owner = "";
						
						if ($i['user_id'] == $_SESSION['user_id']) { 
							$owner = "*";
						}
						
						$prnt .= "<a href='index.php?amn=grp_list&amp;tag=" . $i['tag_body'] . "'>" . $i['tag_body'] . "</a><sup>" .  $i['total'] . $owner . "</sup>, ";
					endforeach;
					$prnt = substr($prnt, 0 ,-2);
					echo $prnt;
					?>
				</p>
				<?php }?>
				
				<?php
				if (isset($tags)) {
				?>
				<p>
					<b><?php echo $lang['txt_tag_subjects'];?></b><br />
					<?php
					$prnt = "";
					foreach($tags as $key => $i):
					
						$owner = "";
						
						if ($i['user_id'] == $_SESSION['user_id']) { 
							$owner = "*";
						}
						
						$prnt .= "<a href='index.php?amn=grp_list&amp;tag=" . $i['tag_body'] . "'>" . $i['tag_body'] . "</a><sup>" .  $i['total'] . $owner . "</sup>, ";
					endforeach;
					$prnt = substr($prnt, 0 ,-2);
					echo $prnt;
					?>
				</p>
				<?php }?>
				
				<?php
				if (!isset($tags) && !isset($group_tags)) {
				?>
				<p>
					<?php echo $lang['template_error']['err_no_items'];?><br />
				</p>
				<?php }?>
			</div>
		</div>
	</div>
</div>

<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<span style="float:left">
				<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('components/core/help.php?help=core_bookmarks');" />
			</span>
			
			<?php echo $lang['hdr_rated'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($rated_subjects)) {
				?>
				<table border="0" cellspacing="" cellpadding="2" width="100%">
				<?php
				foreach($rated_subjects as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><b><?php echo $i['subject_title'];?></b></a><br />
						<?php echo $i['subject_synopsis'];?>
					</td>
					<td align="right" valign="top">
						<?php echo $i['total'];?> votes<br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php
				} else {
				?>
					<p>
						<?php echo $lang['template_error']['err_no_items'];?><br />
					</p>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<span style="float:left">
				<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('components/core/help.php?help=core_bookmarks');" />
			</span>
			
			<?php echo $lang['hdr_recommended'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($recommended_subjects)) {
				?>
				<table border="0" cellspacing="" cellpadding="2" width="100%">
				<?php
				foreach($recommended_subjects as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><b><?php echo $i['subject_title'];?></b></a><br />
						<?php echo $i['subject_synopsis'];?>
					</td>
					<td align="right" valign="top">
						<?php echo $i['total'];?> <?php echo $lang['txt_votes'];?><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php
				} else {
				?>
					<p>
						<?php echo $lang['template_error']['err_no_items'];?><br />
					</p>
				<?php }?>
			</div>
		</div>
	</div>
</div>

==> am_mod_grp_0_3.zip: am_mod_grp_0_3/components/grp/template/barnraiser_01/metadata.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>


<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<a href="#" style="float:left;" onClick="javascript:launchPopupWindow('components/core/help.php?help=core_tags#module_tags');" style="cursor:help;"><img src="<?php echo $template_path_core;?>img/help.png" alt="<?php echo $lang['alt_help'];?>" border="0" /></a>
				
				<h1><?php echo $lang['hdr_cloud'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($group_tags)) {
				?>
				<p>
					<b><?php echo $lang['txt_tag_group'];?></b><br />
					<?php
					$prnt = "";
					foreach($group_tags as $key => $i):
					
						$owner = "";
						
						if (isset($_SESSION['user_id']) && $i['user_id'] == $_SESSION['user_id']) { 
							$owner = "*";
						}
						
						$prnt .= "<a href='index.php?amn=grp_list&amp;tag=" . $i['tag_body'] . "'>" . $i['tag_body'] . "</a><sup>" .  $i['total'] . $owner . "</sup>, ";
					endforeach;
					$prnt = substr($prnt, 0 ,-2);
					echo $prnt;
					?>
				</p>
				<?php }?>
				
				<?php
				if (isset($tags)) {
				?>
				<p>
					<b><?php echo $lang['txt_tag_subjects'];?></b><br />
					<?php
					$prnt = "";
					foreach($tags as $key => $i):
					
						$owner = "";
						
						if (isset($_SESSION['user_id']) && $i['user_id'] == $_SESSION['user_id']) { 
							$owner = "*";
						}
						
						$prnt .= "<a href='index.php?amn=grp_list&amp;tag=" . $i['tag_body'] . "'>" . $i['tag_body'] . "</a><sup>" .  $i['total'] . $owner . "</sup>, ";
					endforeach;
					$prnt = substr($prnt, 0 ,-2);
					echo $prnt;
					?>
				</p>
				<?php }?>
				
				<?php
				if (!isset($tags) && !isset($group_tags)) {
				?>
				<p>
					<?php echo $lang['template_error']['err_no_items'];?><br />
				</p>
				<?php }?>
			</div>
		</div>
	</div>
</div>

<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<a href="#" style="float:left;" onClick="javascript:launchPopupWindow('components/core/help.php?help=core_bookmarks');" style="cursor:help;"><img src="<?php echo $template_path_core;?>img/help.png" alt="<?php echo $lang['alt_help'];?>" border="0" /></a>
				
				<h1><?php echo $lang['hdr_rated'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($rated_subjects)) {
				?>
				<table border="0" cellspacing="" cellpadding="2" width="100%">
				<?php
				foreach($rated_subjects as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><b><?php echo $i['subject_title'];?></b></a><br />
						<?php echo $i['subject_synopsis'];?>
					</td>
					<td align="right" valign="top">
						<?php echo $i['total'];?> votes<br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php
				} else {
				?>
					<p>
						<?php echo $lang['template_error']['err_no_items'];?><br />
					</p>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<a href="#" style="float:left;" onClick="javascript:launchPopupWindow('components/core/help.php?help=core_bookmarks');" style="cursor:help;"><img src="<?php echo $template_path_core;?>img/help.png" alt="<?php echo $lang['alt_help'];?>" border="0" /></a>
				
				<h1><?php echo $lang['hdr_recommended'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($recommended_subjects)) {
				?>
				<table border="0" cellspacing="" cellpadding="2" width="100%">
				<?php
				foreach($recommended_subjects as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $i['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>"><b><?php echo $i['subject_title'];?></b></a><br />
						<?php echo $i['subject_synopsis'];?>
					</td>
					<td align="right" valign="top">
						<?php echo $i['total'];?> <?php echo $lang['txt_votes'];?><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php
				} else {
				?>
					<p>
						<?php echo $lang['template_error']['err_no_items'];?><br />
					</p>
				<?php }?>
			</div>
		</div>
	</div>
</div>
